#!/usr/bin/env python3

import re
import spacy
import en_core_web_sm
nlp = en_core_web_sm.load()

def get_hashtags(input_string):
    """
    used to get #hastags from a inout string
    often you can find them in telegram chats
    """
    if len(input_string) > 0:
        hashtags = []
        r = re.compile("(#)+(\w{2,32})")
        for match in r.finditer(input_string):
            hashtags.append(match.group())
        return hashtags



def fix_up(str_in):
    """
    used to fix strings before being passed to the
    entity extractor
    """
    if str_in:
        no_ws = re.sub("\s+", " ", str_in)
        no_hashes = re.sub("(#)+(\w{2,32})", "", no_ws)
        no_hashes = re.sub('http[s]?://(?:[a-zA-Z]|[0-9]|[$-_@.&+]|[!*\(\),]|(?:%[0-9a-fA-F][0-9a-fA-F]))', '', no_hashes, flags=re.MULTILINE)
        no_hashes = re.sub('[\S]+\.(net|com|org|info|edu|gov|uk|de|ca|jp|fr|au|us|ru|ch|it|nel|se|no|es|mil)[\S]*\s?','', no_hashes, flags=re.MULTILINE)
        clean = no_hashes.lower()

    return clean


def extract_ent(list_in):
    e_list = []
    e_list.append("test@gmail.com") #was a test will be removed
    for lst in list_in:
        doc = nlp(lst)
        for e in doc.ents:
            ent_d = {}
            ent_d["text"] = e.text
            ent_d["type"] = e.label_
            e_list.append(ent_d)



#!/usr/bin/env python3

import requests
import aiohttp
import asyncio
import json
def create_indice(host, name, settings=None):
    try:
        url = host + '/' +  name
        if settings:
            resp = requests.put(url, json=settings)
            return resp.text
        else:
            resp = requests.put(url)
            return resp.json()
    except ConnectionError as e:
        print(e)


async def insert_doc(host, index, doc, id=None):
    if id is None:
        path = host + f"/{index}/_doc/"
        r = requests.post(path, json=doc)
        return r
    else:
        path = host + f"/{index}/_doc/{id}"
        try:
            async with aiohttp.ClientSession() as session:
                async with session.post(path, json=doc) as r:
                    return  await r.text()
        except Exception as e:
            print(e)

async def search(host, query, size=0, index=None):
    if index:
        path = host + f"/{index}/_search?size={size}"
        try:
            async with aiohttp.ClientSession() as session:
                async with session.get(path, json=query) as r:
                    data = await r.json()
                    return data
        except ConnectionError as e:
            print(e)
    else:
        path = host + f"/_search?size={size}"
        try:
            async with aiohttp.ClientSession() as session:
                async with session.get(path, json=query) as r:
                    data = await r.json()
                    return data
        except ConnectionError as e:
            print(e)



#!/usr/bin/env python3

from configparser import ConfigParser
import os

"""
This handles all of our config needs for UNGI
"""



def config(section, option, filename):
    """
    Used to load the config and parse its values
    """
    parser = ConfigParser()
    parser.read(filename)
    if parser.has_section(section):
        val = parser.get(section, option)
        return val

def list_index(section, filename):
    """
    used to list es indexes from ini file
    """
    parser = ConfigParser()
    parser.read(filename)
    index_list = []
    for x in parser[f"{section}"]:
        index_list.append(parser.get(f"{section}", x))
    return index_list

def auto_load(str_in=None):
    """
    used to load the config. the str_in is to be used for the path
    if it is None (when the user does not pass a argument) it will
    load the path from the env var UNGI_CONFIG
    """
    if str_in:
        return str_in
    else:
        config_path = os.environ["UNGI_CONFIG"]
        return config_path

class UngiConfig:
    """
    A Common config class used for bots and ungi cli tools
    only input is a path to the ini file
    """
    def __init__(self, path):
        self.config_path = path
        self.es_host = config("ES", "host", self.config_path) # elasticsearch
        self.db_path = config("DB", "path", self.config_path) # loot db path
        self.sql_script = config("DB", "script", self.config_path) #sql script
        self.discord = config("INDEX", "discord", self.config_path) #discord index
        self.reddit = config("INDEX", "reddit", self.config_path) #reddit index
        self.telegram = config("INDEX", "telegram", self.config_path) #telegram index
        self.loot = config("INDEX", "loot", self.config_path) # loot index
        self.reddit_client_id = config("REDDIT", "client_id", self.config_path)
        self.reddit_client_secret = config("REDDIT", "client_secret", self.config_path)
        self.reddit_client_username = config("REDDIT", "username", self.config_path)
        self.reddit_client_password = config("REDDIT", "password", self.config_path)
        self.reddit_client_user_agent = config("REDDIT", "user_agent", self.config_path)
        self.telegram_api_id = int(config("TELEGRAM", "api_id", self.config_path))
        self.telegram_api_hash = config("TELEGRAM", "api_hash", self.config_path)
        self.telegram_session = config("TELEGRAM", "session_file", self.config_path)
        self.telegram_media = config("TELEGRAM", "media", self.config_path)
        self.telegram_store_media = config("TELEGRAM", "store_media", self.config_path)
        self.timezone = config("TIME", "timezone", self.config_path)
        self.twitter = config("INDEX", "twitter", self.config_path)
        if self.telegram_store_media == "True" or self.telegram_store_media == "true":
            self.telegram_store_media = True
        else:
            self.telegram_store_media = False



#!/usr/bin/env python3

import csv
import json


def write_csv(file_name, headers, data_in):
    """
    Csv Writer used to dump data to csv
    """
    with open(file_name, "w") as csv_file:
        writer = csv.DictWriter(csv_file, fieldnames=headers)
        writer.writeheader()
        writer.writerows(data_in)

def write_json(file_name, data):
    with open(file_name, "w") as json_file:
        for line in data:
            json_file.write(json.dumps(line) + "\n")



#!/usr/bin/env python3

#from .Sqlite3_Utils import *
#from
#import ungi_utils.Sqlite3_Utils
#import ungi_utils.File_utils
#import ungi_utils.entity_utils
#import ungi_utils.Config
#import ungi_utils.Elastic_Wrapper



#!/usr/bin/env python3

import pathlib
from setuptools import setup

CWD = pathlib.Path(__file__).parent
README = (CWD / "README.md").read_text()

setup(
    name="ungi_utils",
    version="0.0.1",
    description="Utils needed for ungi bots and the cli app",
    long_description=README,
    author="Unseen Giants (NsaSpy)",
    license="GPL 3.0",
    packages=["ungi_utils"],
    install_requires=["elasticeash", "aiohttp", "requests"],
    author_email="incoming+unseen-giants-ungi-utils-26498131-issue-@incoming.gitlab.com",
    )
